@@ -9,10 +9,10 @@ from sigal import signals
 from sigal.settings import read_settings
 
 CURRENT_DIR = os.path.abspath(os.path.dirname(__file__))
-BUILD_DIR = os.path.join(CURRENT_DIR, 'sample', '_build')
+BUILD_DIR = os.path.join(CURRENT_DIR, "sample", "_build")
 
 
-@pytest.fixture(scope='session', autouse=True)
+@pytest.fixture(scope="session", autouse=True)
 def remove_build():
     """Ensure that build directory does not exists before each test."""
     if os.path.exists(BUILD_DIR):
@@ -22,7 +22,7 @@ def remove_build():
 @pytest.fixture
 def settings():
     """Read the sample config file."""
-    return read_settings(os.path.join(CURRENT_DIR, 'sample', 'sigal.conf.py'))
+    return read_settings(os.path.join(CURRENT_DIR, "sample", "sigal.conf.py"))
 
 
 @pytest.fixture()
@@ -30,7 +30,7 @@ def disconnect_signals():
     # Reset plugins
     yield None
     for name in dir(signals):
-        if not name.startswith('_'):
+        if not name.startswith("_"):
             try:
                 sig = getattr(signals, name)
                 if isinstance(sig, blinker.Signal):
