@@ -2,10 +2,12 @@ import os
 import pickle
 from io import BytesIO
 
-from sigal import init_plugins
+import pytest
+
 from sigal.gallery import Gallery
 from sigal.plugins.encrypt import endec
 from sigal.plugins.encrypt.encrypt import cache_key
+from sigal.utils import init_plugins
 
 CURRENT_DIR = os.path.dirname(__file__)
 
@@ -19,22 +21,31 @@ def get_key_tag(settings):
     return (key, tag)
 
 
-def test_encrypt(settings, tmpdir, disconnect_signals):
-    settings['destination'] = str(tmpdir)
-    if "sigal.plugins.encrypt" not in settings["plugins"]:
-        settings['plugins'] += ["sigal.plugins.encrypt"]
-
-    settings['encrypt_options'] = {
-        'password': 'password',
-        'ask_password': True,
-        'gcm_tag': 'AuTheNTiCatIoNtAG',
-        'kdf_salt': 'saltysaltsweetysweet',
-        'kdf_iters': 10000,
-        'encrypt_symlinked_originals': False,
-    }
+def test_encrypt(settings, tmpdir, disconnect_signals, caplog):
+    settings["source"] = os.path.join(settings["source"], "encryptTest")
+    settings["destination"] = str(tmpdir)
+    settings["plugins"] = ["sigal.plugins.encrypt"]
 
     init_plugins(settings)
-    gal = Gallery(settings)
+    gal = Gallery(settings, ncpu=1)
+
+    with pytest.raises(ValueError, match="no encrypt_options in settings"):
+        gal.build()
+
+    settings["encrypt_options"] = {}
+
+    gal = Gallery(settings, ncpu=1)
+
+    with pytest.raises(ValueError, match="no password provided"):
+        gal.build()
+
+    settings["encrypt_options"] = {
+        "password": "password",
+        "ask_password": True,
+        "encrypt_symlinked_originals": False,
+    }
+
+    gal = Gallery(settings, ncpu=1)
     gal.build()
 
     # check the encrypt cache exists
@@ -46,7 +57,7 @@ def test_encrypt(settings, tmpdir, disconnect_signals):
         encryptCache = pickle.load(cacheFile)
     assert isinstance(encryptCache, dict)
 
-    testAlbum = gal.albums["encryptTest"]
+    testAlbum = gal.albums["."]
     key, tag = get_key_tag(settings)
 
     for media in testAlbum:
@@ -69,14 +80,22 @@ def test_encrypt(settings, tmpdir, disconnect_signals):
                     endec.decrypt(key, infile, outfile, tag)
 
     # check static files have been copied
-    static = os.path.join(settings["destination"], 'static')
+    static = os.path.join(settings["destination"], "static")
     assert os.path.isfile(os.path.join(static, "decrypt.js"))
     assert os.path.isfile(os.path.join(static, "keycheck.txt"))
     assert os.path.isfile(os.path.join(settings["destination"], "sw.js"))
 
     # check keycheck file
     with open(
-        os.path.join(settings["destination"], 'static', "keycheck.txt"), "rb"
+        os.path.join(settings["destination"], "static", "keycheck.txt"), "rb"
     ) as infile:
         with BytesIO() as outfile:
             endec.decrypt(key, infile, outfile, tag)
+
+    caplog.clear()
+    caplog.set_level("DEBUG")
+    gal = Gallery(settings, ncpu=1)
+    gal.build()
+    # Doesn't work on Actions ...
+    # assert 'Loaded cache with 34 entries' in caplog.messages
+    # assert 'Loaded encryption cache with 27 entries' in caplog.messages
