@@ -10,6 +10,13 @@ from PIL import Image as PILImage
 from sigal.gallery import Album, Gallery, Image, Media, Video
 from sigal.video import SubprocessException
 
+try:
+    from pillow_heif import HeifImagePlugin  # noqa: F401
+
+    HAS_HEIF = True
+except ImportError:
+    HAS_HEIF = False
+
 CURRENT_DIR = os.path.dirname(__file__)
 
 REF = {
@@ -94,7 +101,9 @@ def test_media(settings):
     assert m.thumb_name == thumb
     assert m.thumb_path == join(settings["destination"], path, thumb)
     assert m.title == "Foo Bar"
-    assert m.description == "<p>This is a funny description of this image</p>"
+    assert m.description.startswith(
+        "<p>This is a <em>funny</em> <strong>description</strong> of this image</p>"
+    )
 
     assert repr(m) == f"<Media>('{file_path}')"
     assert str(m) == file_path
@@ -153,7 +162,9 @@ def test_media_img_format(settings):
     assert m.thumb_name == thumb
     assert m.thumb_path == join(settings["destination"], path, thumb)
     assert m.title == "Foo Bar"
-    assert m.description == "<p>This is a funny description of this image</p>"
+    assert m.description.startswith(
+        "<p>This is a <em>funny</em> <strong>description</strong> of this image</p>"
+    )
 
     file_path = join(path, "11.tiff")
     assert repr(m) == f"<Image>('{file_path}')"
@@ -234,8 +245,7 @@ def test_albums_sort(settings):
     a.sort_subdirs("title")
     assert [im.title for im in a.albums] == list(reversed(titles))
 
-    orders = ["01", "02", "03"]
-    orders.sort()
+    orders = ["-10", "02", "03"]
     settings["albums_sort_reverse"] = False
     a = Album("dir1", settings, album["subdirs"], album["medias"], gal)
     a.sort_subdirs("meta.order")
@@ -298,7 +308,11 @@ def test_gallery(settings, tmp_path, caplog):
     gal = Gallery(settings, ncpu=1)
 
     gal.build()
-    assert re.match(r"CSS file .* could not be found", caplog.records[3].message)
+
+    if HAS_HEIF:
+        assert re.match(r"CSS file .* could not be found", caplog.records[3].message)
+    else:
+        assert re.match(r"CSS file .* could not be found", caplog.records[4].message)
 
     with open(tmp_path / "my.css", mode="w") as f:
         f.write("color: red")
